@@ -51,6 +51,7 @@ package com.openexchange.imap;
 
 import gnu.trove.ConcurrentTIntObjectHashMap;
 import java.io.IOException;
+import java.lang.reflect.Field;
 import java.net.InetSocketAddress;
 import java.net.SocketTimeoutException;
 import java.nio.charset.UnsupportedCharsetException;
@@ -70,7 +71,7 @@ import javax.mail.AuthenticationFailedException;
 import javax.mail.MessagingException;
 import javax.mail.event.FolderEvent;
 import javax.mail.event.FolderListener;
-import javax.mail.internet.IDNA;
+import javax.mail.internet.idn.IDNA;
 import javax.security.auth.Subject;
 import org.cliffc.high_scale_lib.NonBlockingHashMap;
 import com.openexchange.config.ConfigurationService;
@@ -238,7 +239,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
 
     /**
      * Drops the user-associated validity.
-     * 
+     *
      * @param userId The user identifier
      * @param contextId The context identifier
      */
@@ -248,7 +249,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
 
     /**
      * Gets the current validity value.
-     * 
+     *
      * @param accountId The account identifier
      * @param session The associated session
      * @return The current validity or <code>0</code> if not initialized, yet
@@ -267,7 +268,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
 
     /**
      * Gets the IMAP validity.
-     * 
+     *
      * @param imapAccess The IMAP access
      * @return The IMAP validity
      */
@@ -295,7 +296,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
 
     /**
      * Increases current validity by one.
-     * 
+     *
      * @param accountId The account identifier
      * @param session The associated session
      * @return The increased validity value
@@ -373,7 +374,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
      * The IMAP session.
      */
     private transient javax.mail.Session imapSession;
-    
+
     /**
      * The Kerberos subject.
      */
@@ -479,7 +480,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
 
     /**
      * Checks the validity for being put into cache.
-     * 
+     *
      * @return <code>true</code> if valid; otherwise <code>false</code>
      */
     public boolean checkValidity() {
@@ -498,7 +499,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
 
     /**
      * Checks if Kerberos authentication is supposed to be performed.
-     * 
+     *
      * @return <code>true</code> for Kerberos authentication; otherwise <code>false</code>
      */
     private boolean isKerberosAuth() {
@@ -769,7 +770,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             return true;
         } catch (final OXException e) {
             if (LOG.isDebugEnabled()) {
-                LOG.debug(new StringBuilder("Ping to IMAP server \"").append(config.getServer()).append("\" failed").toString(), e);
+                LOG.debug(new com.openexchange.java.StringAllocator("Ping to IMAP server \"").append(config.getServer()).append("\" failed").toString(), e);
             }
             return false;
         }
@@ -860,11 +861,11 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                 if (!isEmpty(ip)) {
                     clientIp = ip;
                 } else if (DEBUG) {
-                    LOG.debug(new StringBuilder(256).append("\n\n\tMissing client IP in session \"").append(session.getSessionID()).append(
+                    LOG.debug(new com.openexchange.java.StringAllocator(256).append("\n\n\tMissing client IP in session \"").append(session.getSessionID()).append(
                         "\" of user ").append(session.getUserId()).append(" in context ").append(session.getContextId()).append(".\n"));
                 }
             } else if (DEBUG && MailAccount.DEFAULT_ID == accountId) {
-                LOG.debug(new StringBuilder(256).append("\n\n\tPropagating client IP address disabled on Open-Xchange server \"").append(
+                LOG.debug(new com.openexchange.java.StringAllocator(256).append("\n\n\tPropagating client IP address disabled on Open-Xchange server \"").append(
                     IMAPServiceRegistry.getService(ConfigurationService.class).getProperty("AJP_JVM_ROUTE")).append("\"\n").toString());
             }
             /*
@@ -907,7 +908,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                  * This call is re-invoked during IMAPNotifierTask's run
                  */
                 if (IMAPNotifierRegistry.getInstance().addTaskFor(accountId, session) && INFO) {
-                    final StringBuilder tmp = new StringBuilder("\n\tStarted IMAP notifier for server \"").append(config.getServer());
+                    final com.openexchange.java.StringAllocator tmp = new com.openexchange.java.StringAllocator("\n\tStarted IMAP notifier for server \"").append(config.getServer());
                     tmp.append("\" with login \"").append(user);
                     tmp.append("\" (user=").append(session.getUserId());
                     tmp.append(", context=").append(session.getContextId()).append(").");
@@ -926,7 +927,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
              * Special check for ACLs
              */
             if (config.isSupportsACLs()) {
-                final String key = new StringBuilder(server).append('@').append(port).toString();
+                final String key = new com.openexchange.java.StringAllocator(server).append('@').append(port).toString();
                 Boolean b = aclCapableServers.get(key);
                 if (null == b) {
                     Boolean nb;
@@ -968,7 +969,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
 
     /**
      * Gets a connected IMAP store
-     * 
+     *
      * @param fromCache <code>true</code> from cache; otherwise <code>false</code>
      * @return The connected IMAP store
      * @throws MessagingException If a messaging error occurs
@@ -1171,6 +1172,45 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             failedAuthTimeout = 10000L;
         }
         FAILED_AUTH_TIMEOUT.set(failedAuthTimeout);
+
+        {
+            Field mc;
+            try {
+                mc = IMAPFolder.class.getDeclaredField("messageCache");
+                mc.setAccessible(true);
+            } catch (final SecurityException e) {
+                mc = null;
+            } catch (final NoSuchFieldException e) {
+                mc = null;
+            }
+            IMAPFolderWorker.messageCacheField = mc;
+        }
+
+        {
+            Field mss;
+            try {
+                mss = com.sun.mail.imap.MessageCache.class.getDeclaredField("messages");
+                mss.setAccessible(true);
+            } catch (final SecurityException e) {
+                mss = null;
+            } catch (final NoSuchFieldException e) {
+                mss = null;
+            }
+            IMAPFolderWorker.messagesField = mss;
+        }
+
+        {
+            Field ut;
+            try {
+                ut = IMAPFolder.class.getDeclaredField("uidTable");
+                ut.setAccessible(true);
+            } catch (final SecurityException e) {
+                ut = null;
+            } catch (final NoSuchFieldException e) {
+                ut = null;
+            }
+            IMAPFolderWorker.uidTableField = ut;
+        }
     }
 
     private static synchronized void initMaps() {
