@@ -217,7 +217,7 @@ public class IMAPDefaultFolderChecker {
 
     /**
      * Check presence of default folders.
-     * 
+     *
      * @param key The key for cache look-up
      * @param mailSessionCache The cache
      * @throws MailException If checking default folders' presence fails for any reason
@@ -404,15 +404,55 @@ public class IMAPDefaultFolderChecker {
         return (msg.indexOf("quota") >= 0 || msg.indexOf("limit") >= 0);
     }
 
+    /** Gets fall-back name */
+    private static String getFallbackName(final int index) {
+        switch (index) {
+        case StorageUtility.INDEX_CONFIRMED_HAM:
+            return DefaultFolderNamesProvider.DEFAULT_PROVIDER.getConfirmedHam();
+        case StorageUtility.INDEX_CONFIRMED_SPAM:
+            return DefaultFolderNamesProvider.DEFAULT_PROVIDER.getConfirmedSpam();
+        case StorageUtility.INDEX_DRAFTS:
+            return DefaultFolderNamesProvider.DEFAULT_PROVIDER.getDrafts();
+        case StorageUtility.INDEX_SENT:
+            return DefaultFolderNamesProvider.DEFAULT_PROVIDER.getSent();
+        case StorageUtility.INDEX_SPAM:
+            return DefaultFolderNamesProvider.DEFAULT_PROVIDER.getSpam();
+        case StorageUtility.INDEX_TRASH:
+            return DefaultFolderNamesProvider.DEFAULT_PROVIDER.getTrash();
+        default:
+            return "Nope";
+        }
+    }
+
+    /**
+     * Performs default folder check for specified arguments.
+     *
+     * @param index The index
+     * @param prefix The prefix
+     * @param fullName The full name
+     * @param name The name
+     * @param sep The separator character
+     * @param type The folder type
+     * @param subscribe Whether to subscribe
+     * @param modified Whether folders has been modified during check
+     * @param cache The associated cache
+     * @return Dummy <code>null</code>
+     * @throws OXException If an error occurs
+     */
     protected Callable<Object> performTaskFor(final int index, final String prefix, final String fullName, final String name, final char sep, final int type, final int subscribe, final AtomicBoolean modified, final MailSessionCache cache) throws OXException {
         try {
-            if (null == fullName || 0 == fullName.length()) {
-                setDefaultMailFolder(index, checkDefaultFolder(index, prefix, name, sep, type, subscribe, false, modified), cache);
+            if (isEmpty(fullName)) {
+                if (isEmpty(name)) {
+                    // Neither full name nor name
+                    setDefaultMailFolder(index, checkDefaultFolder(index, prefix, getFallbackName(index), sep, type, subscribe, false, modified), cache);
+                } else {
+                    setDefaultMailFolder(index, checkDefaultFolder(index, prefix, name, sep, type, subscribe, false, modified), cache);
+                }
             } else {
                 setDefaultMailFolder(index, checkDefaultFolder(index, "", fullName, sep, type, subscribe, true, modified), cache);
             }
         } catch (final OXException e) {
-            final StringBuilder sb = new StringBuilder(1024);
+            final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(1024);
             sb.append("Couldn't check default folder: ");
             sb.append((null == fullName ? (prefix + name) : fullName)).append("\n\n");
             appendStackTrace(e.getStackTrace(), sb, new ClassNameMatcher(IMAPDefaultFolderChecker.class.getSimpleName()));
@@ -435,7 +475,7 @@ public class IMAPDefaultFolderChecker {
                 /*
                  * Special handling for over-quota error
                  */
-                final StringBuilder sb = new StringBuilder(1024);
+                final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(1024);
                 sb.append("Couldn't check default folder due to exceeded quota restrictions: ");
                 sb.append((null == fullName ? (prefix + name) : fullName)).append("\n\n");
                 appendStackTrace(e.getStackTrace(), sb, new ClassNameMatcher(IMAPDefaultFolderChecker.class.getSimpleName()));
@@ -444,7 +484,7 @@ public class IMAPDefaultFolderChecker {
                 final OXException warning = MimeMailException.handleMessagingException(e, imapConfig, session).setCategory(Category.CATEGORY_WARNING);
                 imapStore.getImapAccess().addWarnings(Collections.singleton(warning));
             } else {
-                final StringBuilder sb = new StringBuilder(1024);
+                final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(1024);
                 sb.append("Couldn't check default folder: ");
                 sb.append((null == fullName ? (prefix + name) : fullName)).append("\n\n");
                 appendStackTrace(e.getStackTrace(), sb, new ClassNameMatcher(IMAPDefaultFolderChecker.class.getSimpleName()));
@@ -457,6 +497,16 @@ public class IMAPDefaultFolderChecker {
         return null;
     }
 
+    /**
+     * Gets the default folder prefix.
+     *
+     * @param inboxFolder The INBOX folder
+     * @param inboxListEntry The associated LIST/LSUB entry
+     * @param mailSessionCache The associated cache
+     * @return The prefix and separator character as an array
+     * @throws MessagingException If a messaging error occurs
+     * @throws OXException If an error occurs
+     */
     protected String[] getDefaultFolderPrefix(final IMAPFolder inboxFolder, final ListLsubEntry inboxListEntry, final MailSessionCache mailSessionCache) throws MessagingException, OXException {
         /*
          * Check for NAMESPACE capability
@@ -771,12 +821,12 @@ public class IMAPDefaultFolderChecker {
      * Matcher for {@link StackTraceElement}s.
      */
     protected static interface StackTraceElementMatcher {
-        
+
         boolean accepts(StackTraceElement stackTraceElement);
     }
 
     private static final class ClassNameMatcher implements StackTraceElementMatcher {
-        
+
         private final String className;
         private boolean found;
 
@@ -807,12 +857,12 @@ public class IMAPDefaultFolderChecker {
 
     /**
      * Appends stack trace.
-     * 
+     *
      * @param trace The stack trace
      * @param sb The builder
      * @param num The max. number of elements to append
      */
-    protected static void appendStackTrace(final StackTraceElement[] trace, final StringBuilder sb, final StackTraceElementMatcher matcher) {
+    protected static void appendStackTrace(final StackTraceElement[] trace, final com.openexchange.java.StringAllocator sb, final StackTraceElementMatcher matcher) {
         if (null == trace) {
             return;
         }
@@ -851,4 +901,17 @@ public class IMAPDefaultFolderChecker {
         }
     }
 
+    /** Checks for empty string */
+    protected static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final int len = string.length();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < len; i++) {
+            isWhitespace = Character.isWhitespace(string.charAt(i));
+        }
+        return isWhitespace;
+    }
+
 }
