@@ -50,7 +50,10 @@
 package com.openexchange.imap;
 
 import static com.openexchange.mail.dataobjects.MailFolder.DEFAULT_FOLDER_ID;
+import java.lang.reflect.Field;
+import java.util.Arrays;
 import java.util.HashSet;
+import java.util.Hashtable;
 import java.util.Set;
 import javax.mail.Flags;
 import javax.mail.Folder;
@@ -76,6 +79,7 @@ import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.session.Session;
 import com.sun.mail.imap.DefaultFolder;
 import com.sun.mail.imap.IMAPFolder;
+import com.sun.mail.imap.IMAPMessage;
 import com.sun.mail.imap.Rights.Right;
 
 /**
@@ -188,7 +192,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
 
     /**
      * Adds specified IMAP folder to set of maintained opened folders.
-     * 
+     *
      * @param folder The IMAP folder to add
      */
     protected void addOpenedFolder(final IMAPFolder folder) {
@@ -310,6 +314,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
                          */
                         // IMAPCommandsCollection.updateIMAPFolder(imapFolder,
                         // mode);
+                        clearCache(imapFolder);
                         return imapFolder;
                     }
                     /*
@@ -439,4 +444,55 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
         return MailExceptionCode.UNEXPECTED_ERROR.create(e, e.getMessage());
     }
 
+    protected static volatile Field messagesField;
+    protected static volatile Field messageCacheField;
+    protected static volatile Field uidTableField;
+
+    /** Clears the cache */
+    protected static void clearCache(final IMAPFolder imapFolder) {
+        if (null == imapFolder) {
+            return;
+        }
+        final Field messageCacheField = IMAPFolderWorker.messageCacheField;
+        if (null == messageCacheField) {
+            return;
+        }
+        final Field messagesField = IMAPFolderWorker.messagesField;
+        if (null == messagesField) {
+            return;
+        }
+        final Field uidTableField = IMAPFolderWorker.uidTableField;
+        if (null == uidTableField) {
+            return;
+        }
+
+        try {
+            final com.sun.mail.imap.MessageCache mc = (com.sun.mail.imap.MessageCache) messageCacheField.get(imapFolder);
+            if (null != mc) {
+                final IMAPMessage[] messages = (IMAPMessage[]) messagesField.get(mc);
+                if (null != messages) {
+                    Arrays.fill(messages, null);
+                }
+            }
+
+            final Hashtable<?, ?> uidTable = (Hashtable<?, ?>) uidTableField.get(imapFolder);
+            if (null != uidTable) {
+                uidTable.clear();
+            }
+        } catch (final IllegalArgumentException e) {
+            LOG.error(e.getMessage(), e);
+        } catch (final IllegalAccessException e) {
+            LOG.error(e.getMessage(), e);
+        }
+    }
+
+    /** Safely clears the cache */
+    protected static void clearCacheSafe(final IMAPFolder imapFolder) {
+        try {
+            clearCache(imapFolder);
+        } catch (Exception e) {
+            // Ignore
+        }
+    }
+
 }
